.. pypasswd documentation master file, created by
   sphinx-quickstart on Mon Nov  2 14:02:23 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pypasswd's documentation!
====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Password Generator
==================

.. automodule:: pypasswd.generator
   :special-members:
   :private-members:
   :members:
   :exclude-members: __dict__, __weakref__
